@@ -55,10 +55,13 @@ from yellowdog_cli.utils.entity_utils import (
     get_all_roles,
     get_all_users,
     get_application_groups,
+    get_compute_requirement_templates,
+    get_compute_source_templates,
     get_filtered_work_requirements,
-    get_task_groups_from_wr_summary,
+    get_task_groups_from_wr_by_id,
     get_tasks,
     get_user_groups,
+    get_worker_pools,
     list_matching_object_paths,
     substitute_ids_for_names_in_crt,
     substitute_image_family_id_for_name_in_cst,
@@ -254,7 +257,7 @@ def list_work_requirements():
 
 
 def list_task_groups(work_summary: WorkRequirementSummary):
-    task_groups: List[TaskGroup] = get_task_groups_from_wr_summary(
+    task_groups: List[TaskGroup] = get_task_groups_from_wr_by_id(
         CLIENT, work_summary.id
     )
     task_groups = sorted_objects(task_groups)
@@ -326,10 +329,13 @@ def list_object_paths():
 
 
 def list_worker_pools():
-    print_log(f"Displaying Worker Pools in namespace '{CONFIG_COMMON.namespace}'")
+    print_log(
+        f"Displaying Worker Pools in namespace '{CONFIG_COMMON.namespace}' "
+        f"with '{CONFIG_COMMON.name_tag}' in name"
+    )
 
-    worker_pool_summaries: List[WorkerPoolSummary] = (
-        CLIENT.worker_pool_client.find_all_worker_pools()
+    worker_pool_summaries: List[WorkerPoolSummary] = get_worker_pools(
+        CLIENT, CONFIG_COMMON.namespace, CONFIG_COMMON.name_tag
     )
 
     excluded_states = (
@@ -556,20 +562,18 @@ def list_compute_requirement_templates():
     Print the list of Compute Requirement Templates, filtered on Namespace
     and Name. Set these both to empty strings to generate an unfiltered list.
     """
-    cr_templates: List[ComputeRequirementTemplateSummary] = (
-        CLIENT.compute_client.find_all_compute_requirement_templates()
-    )
     print_log(
         "Listing Compute Requirement Templates in namespace "
         f"'{CONFIG_COMMON.namespace}' with names including "
         f"'{CONFIG_COMMON.name_tag}'"
     )
-    cr_templates = [
-        crt
-        for crt in cr_templates
-        if (CONFIG_COMMON.namespace in ("" if crt.namespace is None else crt.namespace))
-        and CONFIG_COMMON.name_tag in crt.name
-    ]
+
+    cr_templates: List[ComputeRequirementTemplateSummary] = (
+        get_compute_requirement_templates(
+            CLIENT, CONFIG_COMMON.namespace, CONFIG_COMMON.name_tag
+        )
+    )
+
     if len(cr_templates) == 0:
         print_log("No matching Compute Requirement Templates found")
         return
@@ -609,20 +613,17 @@ def list_compute_source_templates():
     Print the list of Compute Source Templates, filtered on Namespace
     and Name. Set these both to empty strings to generate an unfiltered list.
     """
-    cs_templates: List[ComputeSourceTemplateSummary] = (
-        CLIENT.compute_client.find_all_compute_source_templates()
-    )
+
     print_log(
         "Listing Compute Source Templates in namespace "
         f"'{CONFIG_COMMON.namespace}' with names including "
         f"'{CONFIG_COMMON.name_tag}'"
     )
-    cs_templates = [
-        cst
-        for cst in cs_templates
-        if (CONFIG_COMMON.namespace in ("" if cst.namespace is None else cst.namespace))
-        and CONFIG_COMMON.name_tag in cst.name
-    ]
+
+    cs_templates = get_compute_source_templates(
+        CLIENT, namespace=CONFIG_COMMON.namespace, name=CONFIG_COMMON.name_tag
+    )
+
     if len(cs_templates) == 0:
         print_log("No matching Compute Source Templates found")
         return
