@@ -122,6 +122,7 @@ class CLIParser:
         )
         parser.add_argument(
             "--print-pid",
+            "--pp",
             action="store_true",
             required=False,
             help="include the process ID of this CLI invocation alongside timestamp in logging messages",
@@ -162,7 +163,7 @@ class CLIParser:
                 nargs="?",
                 const="",
                 help=(
-                    "the namespace to use when creating and identifying entities;"
+                    "the namespace to use when specifying entities;"
                     " this is set to '' if the option is provided without a value"
                 ),
                 metavar="<namespace>",
@@ -184,7 +185,6 @@ class CLIParser:
                 metavar="<tag>",
             )
 
-        # Namespace and tag attributes are defaulted to "" when using 'yd-list'
         if any(module in sys.argv[0] for module in ["list"]):
             parser.add_argument(
                 "--namespace",
@@ -193,10 +193,11 @@ class CLIParser:
                 required=False,
                 nargs="?",
                 const="",
-                default="",
-                help="the namespace to search when listing entities",
+                # default="",
+                help="the namespace to use when listing entities",
                 metavar="<namespace>",
             )
+            # Tag attribute is defaulted to "" when using 'yd-list'
             parser.add_argument(
                 "--tag",
                 "-t",
