@@ -11,7 +11,6 @@ from yellowdog_client.model import (
     AllowanceSearch,
     Application,
     ApplicationSearch,
-    ComputeRequirement,
     ComputeRequirementSearch,
     ComputeRequirementStatus,
     ComputeRequirementTemplate,
@@ -54,14 +53,14 @@ from yellowdog_cli.utils.ydid_utils import YDIDType, get_ydid_type
 
 
 @lru_cache
-def get_task_groups_from_wr_summary(
-    client: PlatformClient, wr_summary_id: str
+def get_task_groups_from_wr_by_id(
+    client: PlatformClient, wr_id: str
 ) -> List[TaskGroup]:
     """
     Get the list of the Work Requirement's Task Groups.
     Cache results to avoid repeatedly hitting the API for the same thing.
     """
-    work_requirement = client.work_client.get_work_requirement_by_id(wr_summary_id)
+    work_requirement = client.work_client.get_work_requirement_by_id(wr_id)
     return work_requirement.taskGroups
 
 
@@ -72,7 +71,7 @@ def get_task_group_name(
     Function to find the Task Group Name for a given Task
     within a Work Requirement.
     """
-    for task_group in get_task_groups_from_wr_summary(client, wr_summary.id):
+    for task_group in get_task_groups_from_wr_by_id(client, wr_summary.id):
         if task.taskGroupId == task_group.id:
             return task_group.name
     return ""  # Shouldn't get here
@@ -89,31 +88,27 @@ def get_filtered_work_requirements(
     Get a list of Work Requirements filtered by namespace, tag
     and status. Supply either include_filter OR exclude_filter.
     """
-    filtered_work_summaries: List[WorkRequirementSummary] = []
 
-    wr_search = WorkRequirementSearch(namespaces=[namespace], tag=tag)
+    if include_filter is None:
+        wr_search = WorkRequirementSearch(namespaces=[namespace], tag=tag)
+    else:
+        wr_search = WorkRequirementSearch(
+            namespaces=[namespace], tag=tag, statuses=include_filter
+        )
+
     wr_search_client = client.work_client.get_work_requirements(wr_search)
-
     work_requirement_summaries: List[WorkRequirementSummary] = (
         wr_search_client.list_all()
     )
 
-    for work_summary in work_requirement_summaries:
-        work_summary.tag = "" if work_summary.tag is None else work_summary.tag
-        work_summary.namespace = (
-            "" if work_summary.namespace is None else work_summary.namespace
-        )
-        if namespace in work_summary.namespace and tag in work_summary.tag:
-            if include_filter is not None:
-                if work_summary.status in include_filter:
-                    filtered_work_summaries.append(work_summary)
-                    continue
-            if exclude_filter is not None:
-                if work_summary.status not in exclude_filter:
-                    filtered_work_summaries.append(work_summary)
-                    continue
+    if include_filter is not None or exclude_filter is None:
+        return work_requirement_summaries
 
-    return filtered_work_summaries
+    return [
+        work_summary
+        for work_summary in work_requirement_summaries
+        if work_summary.status not in exclude_filter
+    ]
 
 
 @lru_cache
@@ -142,7 +137,7 @@ def get_worker_pool_id_by_name(
         except:
             return
 
-    return _find_id_by_name(worker_pool_name, client, get_all_worker_pools)
+    return _find_id_by_name(worker_pool_name, client, get_worker_pools)
 
 
 def get_compute_requirement_id_by_name(
@@ -154,26 +149,31 @@ def get_compute_requirement_id_by_name(
     Find a Compute Requirement ID by its name.
     Restrict search by status.
     """
-    cr_search = ComputeRequirementSearch(statuses=statuses)
+    cr_search = ComputeRequirementSearch(
+        name=compute_requirement_name, statuses=statuses
+    )
     search_client: SearchClient = client.compute_client.get_compute_requirements(
         cr_search
     )
-    compute_requirements: List[ComputeRequirement] = search_client.list_all()
-
-    for compute_requirement in compute_requirements:
-        if compute_requirement.name == compute_requirement_name:
-            return compute_requirement.id
+    try:
+        return search_client.list_all()[0].id
+    except IndexError:
+        return None
 
 
 def get_work_requirement_summary_by_name_or_id(
-    client: PlatformClient, work_requirement_name_or_id: str
+    client: PlatformClient,
+    work_requirement_name_or_id: str,
+    namespace: str = None,
 ) -> Optional[WorkRequirementSummary]:
     """
     Get a Work Requirement Summary by its name or ID.
+    Scoped by namespace.
     """
-    work_requirement_summaries: List[WorkRequirementSummary] = (
-        client.work_client.find_all_work_requirements()
+    work_requirement_summaries = get_work_requirement_summaries(
+        client, namespace=namespace
     )
+
     for work_requirement_summary in work_requirement_summaries:
         if (
             work_requirement_summary.name == work_requirement_name_or_id
@@ -181,6 +181,8 @@ def get_work_requirement_summary_by_name_or_id(
         ):
             return work_requirement_summary
 
+    return None
+
 
 def _find_id_by_name(
     name: str, client: PlatformClient, find_function: Callable
@@ -230,18 +232,20 @@ def find_compute_source_template_id_by_name(
     Find a Compute Source Template id by name.
     Compute Source Template names are unique within a namespace.
     """
-    return _find_id_by_name(name, client, get_all_compute_source_templates)
+    return _find_id_by_name(name, client, get_compute_source_templates)
 
 
 @lru_cache
-def get_all_compute_source_templates(
-    client: PlatformClient, namespace: Optional[str]
+def get_compute_source_templates(
+    client: PlatformClient,
+    namespace: Optional[str] = None,
+    name: Optional[str] = None,
 ) -> List[ComputeSourceTemplateSummary]:
     """
-    Cache the list of Compute Source Templates.
+    Cache the list of Compute Source Templates, scoped by namespace and name.
     """
     cst_search = ComputeSourceTemplateSearch(
-        namespaces=None if namespace in [None, ""] else [namespace]
+        name=name, namespaces=None if namespace in [None, ""] else [namespace]
     )
     cst_search_client: SearchClient = (
         client.compute_client.get_compute_source_templates(cst_search)
@@ -249,11 +253,26 @@ def get_all_compute_source_templates(
     return cst_search_client.list_all()
 
 
+def get_work_requirement_summaries(
+    client: PlatformClient,
+    namespace: Optional[str] = None,
+    name: Optional[str] = None,
+) -> List[WorkRequirementSummary]:
+    """
+    Get the list of Work Requirement summaries, scoped by namespace and name.
+    """
+    wr_search = WorkRequirementSearch(
+        name=name, namespaces=None if namespace in [None, ""] else [namespace]
+    )
+    wr_search_client: SearchClient = client.work_client.get_work_requirements(wr_search)
+    return wr_search_client.list_all()
+
+
 def clear_compute_source_template_cache():
     """
     Clear the cache of Compute Source Templates.
     """
-    get_all_compute_source_templates.cache_clear()
+    get_compute_source_templates.cache_clear()
 
 
 def find_compute_requirement_template_id_by_name(
@@ -263,18 +282,21 @@ def find_compute_requirement_template_id_by_name(
     Find the Compute Requirement Template ID that matches the
     provided name. Names are unique within a namespace.
     """
-    return _find_id_by_name(name, client, get_all_compute_requirement_templates)
+    return _find_id_by_name(name, client, get_compute_requirement_templates)
 
 
 @lru_cache
-def get_all_compute_requirement_templates(
-    client: PlatformClient, namespace: Optional[str]
+def get_compute_requirement_templates(
+    client: PlatformClient,
+    namespace: Optional[str] = None,
+    name: Optional[str] = None,
 ) -> List[ComputeRequirementTemplateSummary]:
     """
-    Cache the list of Compute Requirement Templates.
+    Cache the list of Compute Requirement Templates, scoped by namespace
+    and name.
     """
     crt_search = ComputeRequirementTemplateSearch(
-        namespaces=None if namespace in [None, ""] else [namespace]
+        name=name, namespaces=None if namespace in [None, ""] else [namespace]
     )
     crt_search_client: SearchClient = (
         client.compute_client.get_compute_requirement_templates(crt_search)
@@ -286,7 +308,7 @@ def clear_compute_requirement_template_cache():
     """
     Clear the cache of Compute Requirement Templates.
     """
-    get_all_compute_requirement_templates.cache_clear()
+    get_compute_requirement_templates.cache_clear()
 
 
 def get_compute_requirement_id_by_worker_pool_id(
@@ -300,16 +322,19 @@ def get_compute_requirement_id_by_worker_pool_id(
     )
     if isinstance(worker_pool, ProvisionedWorkerPool):
         return worker_pool.computeRequirementId
+    return None
 
 
-def get_all_worker_pools(
-    client: PlatformClient, namespace: Optional[str]
+def get_worker_pools(
+    client: PlatformClient,
+    namespace: Optional[str] = None,
+    name: Optional[str] = None,
 ) -> List[WorkerPoolSummary]:
     """
-    Return all Worker Pool summaries for a namespace.
+    Return all Worker Pool summaries for a namespace, name.
     """
     wp_search = WorkerPoolSearch(
-        namespaces=None if namespace in [None, ""] else [namespace]
+        name=name, namespaces=None if namespace in [None, ""] else [namespace]
     )
     wp_search_client: SearchClient = client.worker_pool_client.get_worker_pools(
         wp_search
